! ------------------------------------------------------------------------
!>  \brief Module for testing Log Messages module
! ------------------------------------------------------------------------
MODULE log_messages_test
USE fruit             !> Unit testing framework
USE system_constants  !> Global system constants (for max string length)
USE log_messages      !> Log/error message and sender codes

IMPLICIT NONE


CONTAINS


! ************************************************************************
! TEST MESSAGE CODES
! ************************************************************************


! ------------------------------------------------------------------------
!>  \test Test for ALLOC message code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Message code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding message code.
! ------------------------------------------------------------------------
SUBROUTINE test_ALLOC_message_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_ALLOC_message_code'
  INTEGER, PARAMETER :: code = ALLOC
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Failed to allocate memory'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getMsg(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_ALLOC_message_code


! ------------------------------------------------------------------------
!>  \test Test for DIMEN message code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Message code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding message code.
! ------------------------------------------------------------------------
SUBROUTINE test_DIMEN_message_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_DIMEN_message_code'
  INTEGER, PARAMETER :: code = DIMEN
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Size of data structure does not match size of target data structure'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getMsg(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_DIMEN_message_code


! ------------------------------------------------------------------------
!>  \test Test for EXCEED message code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Message code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding message code.
! ------------------------------------------------------------------------
SUBROUTINE test_EXCEED_message_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_EXCEED_message_code'
  INTEGER, PARAMETER :: code = EXCEED
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Data value exceeds a defined minimum or maximum'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getMsg(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_EXCEED_message_code


! ------------------------------------------------------------------------
!>  \test Test for EXISTS message code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Message code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding message code.
! ------------------------------------------------------------------------
SUBROUTINE test_EXISTS_message_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_EXISTS_message_code'
  INTEGER, PARAMETER :: code = EXISTS
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'File does not exist'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getMsg(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_EXISTS_message_code


! ------------------------------------------------------------------------
!>  \test Test for FORMT message code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Message code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding message code.
! ------------------------------------------------------------------------
SUBROUTINE test_FORMT_message_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_FORMT_message_code'
  INTEGER, PARAMETER :: code = FORMT
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'File data is not in expected format'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getMsg(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_FORMT_message_code


! ------------------------------------------------------------------------
!>  \test Test for POSIT message code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Message code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding message code.
! ------------------------------------------------------------------------
SUBROUTINE test_POSIT_message_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_POSIT_message_code'
  INTEGER, PARAMETER :: code = POSIT
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Index exceeds size of data structure'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getMsg(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_POSIT_message_code


! ------------------------------------------------------------------------
!>  \test Test for POSDEF message code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Message code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding message code.
! ------------------------------------------------------------------------
SUBROUTINE test_POSDEF_message_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_POSDEF_message_code'
  INTEGER, PARAMETER :: code = POSDEF
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Matrix is not positive definite'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getMsg(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_POSDEF_message_code


! ------------------------------------------------------------------------
!>  \test Test for SZE message code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Message code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding message code.
! ------------------------------------------------------------------------
SUBROUTINE test_SZE_message_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_SZE_message_code'
  INTEGER, PARAMETER :: code = SZE
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Specified size of data structure exceeds minimum or maximum allowable size'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getMsg(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_SZE_message_code


! ------------------------------------------------------------------------
!>  \test Test for TYP message code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Message code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding message code.
! ------------------------------------------------------------------------
SUBROUTINE test_TYP_message_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_TYP_message_code'
  INTEGER, PARAMETER :: code = TYP
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Specified material property does not correspond to material type'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getMsg(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_TYP_message_code


! ------------------------------------------------------------------------
!>  \test Test for unexpected message code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Message code (not in enumerated list of message codes)
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for a
!!  non-existent message code.
! ------------------------------------------------------------------------
SUBROUTINE test_unexpected_message_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_unexpected_message_code'
  INTEGER, PARAMETER :: code = 100
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Could not find log message code'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getMsg(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_unexpected_message_code



! ************************************************************************
! TEST SENDER CODES
! ************************************************************************


! ------------------------------------------------------------------------
!>  \test Test for BFCRDR sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_BFCRDR_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_BFCRDR_sender_code'
  INTEGER, PARAMETER :: code = BFCRDR
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Body Force Reader'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_BFCRDR_sender_code


! ------------------------------------------------------------------------
!>  \test Test for BNDDAT sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_BNDDAT_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_BNDDAT_sender_code'
  INTEGER, PARAMETER :: code = BNDDAT
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Boundary Data'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_BNDDAT_sender_code


! ------------------------------------------------------------------------
!>  \test Test for BNDRDR sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_BNDRDR_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_BNDRDR_sender_code'
  INTEGER, PARAMETER :: code = BNDRDR
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Boundary File Reader'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_BNDRDR_sender_code


! ------------------------------------------------------------------------
!>  \test Test for BSYMAT sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_BSYMAT_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_BSYMAT_sender_code'
  INTEGER, PARAMETER :: code = BSYMAT
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Banded Symmetric Matrix'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_BSYMAT_sender_code


! ------------------------------------------------------------------------
!>  \test Test for CNSMAT sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_CNSMAT_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_CNSMAT_sender_code'
  INTEGER, PARAMETER :: code = CNSMAT
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Constitutive Matrix'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_CNSMAT_sender_code


! ------------------------------------------------------------------------
!>  \test Test for DMNRDR sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_DMNRDR_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_DMNRDR_sender_code'
  INTEGER, PARAMETER :: code = DMNRDR
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Domain File Reader'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_DMNRDR_sender_code


! ------------------------------------------------------------------------
!>  \test Test for DNSMAT sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_DNSMAT_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_DNSMAT_sender_code'
  INTEGER, PARAMETER :: code = DNSMAT
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Dense Matrix'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_DNSMAT_sender_code


! ------------------------------------------------------------------------
!>  \test Test for FLDDAT sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_FLDDAT_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_FLDDAT_sender_code'
  INTEGER, PARAMETER :: code = FLDDAT
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Field Data'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_FLDDAT_sender_code


! ------------------------------------------------------------------------
!>  \test Test for ICTRDR sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_ICTRDR_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_ICTRDR_sender_code'
  INTEGER, PARAMETER :: code = ICTRDR
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Initial Tensor Field Reader'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_ICTRDR_sender_code


! ------------------------------------------------------------------------
!>  \test Test for ICVRDR sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_ICVRDR_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_ICVRDR_sender_code'
  INTEGER, PARAMETER :: code = ICVRDR
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Initial Vector Field Reader'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_ICVRDR_sender_code


! ------------------------------------------------------------------------
!>  \test Test for KBCRDR sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_KBCRDR_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_KBCRDR_sender_code'
  INTEGER, PARAMETER :: code = KBCRDR
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Kinematic BC Reader'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_KBCRDR_sender_code


! ------------------------------------------------------------------------
!>  \test Test for LINSLV sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_LINSLV_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_LINSLV_sender_code'
  INTEGER, PARAMETER :: code = LINSLV
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Linear Solver'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_LINSLV_sender_code


! ------------------------------------------------------------------------
!>  \test Test for MTLDAT sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_MTLDAT_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_MTLDAT_sender_code'
  INTEGER, PARAMETER :: code = MTLDAT
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Material Property Data'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_MTLDAT_sender_code


! ------------------------------------------------------------------------
!>  \test Test for MTLRDR sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_MTLRDR_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_MTLRDR_sender_code'
  INTEGER, PARAMETER :: code = MTLRDR
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Material File Reader'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_MTLRDR_sender_code


! ------------------------------------------------------------------------
!>  \test Test for NBCRDR sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_NBCRDR_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_NBCRDR_sender_code'
  INTEGER, PARAMETER :: code = NBCRDR
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Natural BC Reader'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_NBCRDR_sender_code


! ------------------------------------------------------------------------
!>  \test Test for TNSWTR sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_TNSWTR_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_TNSWTR_sender_code'
  INTEGER, PARAMETER :: code = TNSWTR
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Tensor Field Writer'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_TNSWTR_sender_code


! ------------------------------------------------------------------------
!>  \test Test for VECTOR sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_VECTOR_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_VECTOR_sender_code'
  INTEGER, PARAMETER :: code = VECTOR
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Vector Data Type'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_VECTOR_sender_code


! ------------------------------------------------------------------------
!>  \test Test for VECWTR sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for the
!!  corresponding sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_VECWTR_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_VECWTR_sender_code'
  INTEGER, PARAMETER :: code = VECWTR
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Vector Field Writer'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_VECWTR_sender_code


! ------------------------------------------------------------------------
!>  \test Test for unexpected sender code
!!
!!  \param unit_name  Name of unit test (for FRUIT)
!!  \param code       Sender code (not in enumerated list of sender codes)
!!  \param expected   Expected message
!!  \param actual     Actual message
!!
!!  This test checks that the correct message is returned for a
!!  non-existent sender code.
! ------------------------------------------------------------------------
SUBROUTINE test_unexpected_sender_code
  CHARACTER (LEN=*), PARAMETER :: unit_name = 'test_unexpected_sender_code'
  INTEGER, PARAMETER :: code = 100
  CHARACTER(LEN=MAXLEN), PARAMETER :: expected = 'Could not find sender code'
  CHARACTER(LEN=MAXLEN) :: actual

  !> initialize unit test
  CALL set_unit_name(unit_name)

  actual = msg_getSdr(code)

  CALL assertEquals(TRIM(expected),TRIM(actual))

END SUBROUTINE test_unexpected_sender_code


END MODULE log_messages_test
